ui

package
v0.8.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 30, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Model

type Model struct {
	// contains filtered or unexported fields
}

Model is the main bubbletea model.

func NewModel

func NewModel(provider core.SessionProvider) Model

func (Model) Init

func (m Model) Init() tea.Cmd

func (Model) Update

func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd)

func (Model) View

func (m Model) View() string

type Theme added in v0.8.1

type Theme struct {
	Primary     lipgloss.Color
	Accent      lipgloss.Color
	Warning     lipgloss.Color
	Muted       lipgloss.Color
	Text        lipgloss.Color
	Subtext     lipgloss.Color
	Border      lipgloss.Color
	BorderFocus lipgloss.Color
	SelectionBg lipgloss.Color

	// Title bar foreground colors (rendered on Primary background)
	TitleText    lipgloss.Color
	TitleSubtext lipgloss.Color
	TitleMuted   lipgloss.Color
	TitleWarning lipgloss.Color

	HelpBg    lipgloss.Color
	HelpKeyBg lipgloss.Color
	ModalBg   lipgloss.Color
	OverlayBg lipgloss.Color

	// Activity colors
	ActivityWaiting    lipgloss.Color
	ActivityThinking   lipgloss.Color
	ActivityCompacting lipgloss.Color
	ActivityReading    lipgloss.Color
	ActivityWriting    lipgloss.Color
	ActivityRunning    lipgloss.Color
	ActivitySearching  lipgloss.Color
	ActivityBrowsing   lipgloss.Color
	ActivitySpawning   lipgloss.Color
}

Theme holds all TUI colors. Each field is a lipgloss.Color so themes can be swapped at startup without touching rendering code.

func DarkTheme added in v0.8.1

func DarkTheme() Theme

DarkTheme returns the default dark terminal theme.

func LightTheme added in v0.8.1

func LightTheme() Theme

LightTheme returns a theme optimized for light terminal backgrounds.

func LoadTheme added in v0.8.1

func LoadTheme(name string) Theme

LoadTheme returns the theme for the given name. Falls back to dark.

Jump to